react-loadable-ssr-addon is authored by: 

* Alexey Pyltsyn <lex61rus@gmail.com>
* Endi <endiliey@gmail.com>
* Jérémie Parker <gitkraken@jeremie-parker.com>
* Marcos <contact@themgoncalves.com>
* Marcos Gonçalves <contact@themgoncalves.com>
* Ngoc Phuong <nguyenngocphuongnb@gmail.com>
* Phuong Nguyen <nguyenngocphuongnb@gmail.com>
* Reece Dunham <me@rdil.rocks>
* Sébastien Lorber <slorber@users.noreply.github.com>
* dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>
* endiliey <endiliey@gmail.com>
* slorber <lorber.sebastien@gmail.com>
